@@ -46,6 +46,7 @@ __all__ = (
     "OnSuccessTypeDef",
     "ProvisionedConcurrencyConfigListItemTypeDef",
     "ResponseMetadata",
+    "SourceAccessConfigurationTypeDef",
     "TracingConfigResponseTypeDef",
     "VpcConfigResponseTypeDef",
     "AddLayerVersionPermissionResponseTypeDef",
@@ -138,6 +139,8 @@ EventSourceMappingConfigurationTypeDef = TypedDict(
     "EventSourceMappingConfigurationTypeDef",
     {
         "UUID": str,
+        "StartingPosition": Literal["TRIM_HORIZON", "LATEST", "AT_TIMESTAMP"],
+        "StartingPositionTimestamp": datetime,
         "BatchSize": int,
         "MaximumBatchingWindowInSeconds": int,
         "ParallelizationFactor": int,
@@ -149,6 +152,8 @@ EventSourceMappingConfigurationTypeDef = TypedDict(
         "StateTransitionReason": str,
         "DestinationConfig": "DestinationConfigTypeDef",
         "Topics": List[str],
+        "Queues": List[str],
+        "SourceAccessConfigurations": List["SourceAccessConfigurationTypeDef"],
         "MaximumRecordAgeInSeconds": int,
         "BisectBatchOnFunctionError": bool,
         "MaximumRetryAttempts": int,
@@ -333,6 +338,10 @@ ResponseMetadata = TypedDict(
     },
 )
 
+SourceAccessConfigurationTypeDef = TypedDict(
+    "SourceAccessConfigurationTypeDef", {"Type": Literal["BASIC_AUTH"], "URI": str}, total=False
+)
+
 TracingConfigResponseTypeDef = TypedDict(
     "TracingConfigResponseTypeDef", {"Mode": Literal["Active", "PassThrough"]}, total=False
 )
